==> flyspray_0.9.6a.orig.tar.gz: flyspray-0.9.6/lang/pl/main.php <==
<?php

// Tłumaczenie na języki polski
// Translation to Polish
//
// Tomek 'TomasH' Zielinski
// tomash@fidonet.org.pl, tomash@4net.pl
//
// Uzupełnienie od wersji 0.9.5:
// Konrad Roziewski <konrad#suwalki-com-pl>

$language = array (

'filenotexist'	=>	'Plik nie istnieje. Skontaktuj się z administratorem projektu.',
'showtask'	=>	'Pokaż zgłoszenie',
'now'			=>	'Teraz',
'go'		=>	'Idź!',
'opentaskanon'	=>	'Utwórz anonimowo nowe zgłoszenie',
'register'	=>	'Zarejestruj nowe konto',
'loggedinas'	=>	'Zalogowany jako',
//'mytasks'	=>	'Przydzielone mi zgłoszenia',
'addnewtask'	=>	'Dodaj nowe zgłoszenie',
'reports'		=>	'Raporty',
'editmydetails'	=>	'Edytuj moje dane',
'changepassword'=>	'Zmień hasło',
'logout'	=>	'Wylogowanie',
'options'	=>	'Ustawienia',
'usersandgroups'=>	'Użytkownicy i grupy',
'tasktypes'	=>	'Typy zgłoszeń',
'categories'	=>	'Kategorie',
'operatingsystems'	=>	'Systemy operacyjne',
'resolutions'	=>	'Decyzje',
'versions'	=>	'Wersje',
'severities'	=>	'Dotkliwość',
'disabledaccount'	=>	'Twoje konto jest nieaktywne!<br>Wylogowano...',
'poweredby'	=>	'Napędzane przez Flyspray',

// Added in version 0.9.5

//'selectproject'	=>	'Lista zgłoszeń projektu:',
'show'		=>	'Pokaż',
'projects'	=>	'Projekty',
'adminmenu'	=>	'Menu Administratora',

// Added in version 0.9.6
'duplicated'	    =>	'Akcja powtórzona. Nastąpi przekierowanie na stronę główną.',
'allprojects'       =>	'Wszystkie projekty',
'selectproject'		=>	'dla projektu:',
'tasksall'          =>  'Wszystkie zgłoszenia',
'tasksassigned'     =>  'Przydzielone mi',
'tasksreported'     =>  'Zgłoszone przeze mnie',
'taskswatched'      =>  'Obserwowane przeze mnie',
'lastsearch'	    =>  'Ostatnio wyszukiwane',


);
// vim:fenc=utf-8:enc=utf-8
?>

==> flyspray_0.9.7.orig.tar.gz: flyspray-0.9.7/lang/pl/main.php <==
<?php

// Tłumaczenie na języki polski
// Translation to Polish
//
// Tomek 'TomasH' Zielinski
// tomash@fidonet.org.pl, tomash@4net.pl
//
// Uzupełnienie od wersji 0.9.5:
// Konrad Roziewski <konrad#suwalki-com-pl>

$language = array (

'filenotexist'	=>	'Plik nie istnieje. Skontaktuj się z administratorem projektu.',
'showtask'	=>	'Pokaż zgłoszenie',
'now'			=>	'Teraz',
'go'		=>	'Idź!',
'opentaskanon'	=>	'Utwórz anonimowo nowe zgłoszenie',
'register'	=>	'Zarejestruj nowe konto',
'loggedinas'	=>	'Zalogowany jako',
//'mytasks'	=>	'Przydzielone mi zgłoszenia',
'addnewtask'	=>	'Dodaj nowe zgłoszenie',
'reports'		=>	'Raporty',
'editmydetails'	=>	'Edytuj moje dane',
'changepassword'=>	'Zmień hasło',
'logout'	=>	'Wylogowanie',
'options'	=>	'Ustawienia',
'usersandgroups'=>	'Użytkownicy i grupy',
'tasktypes'	=>	'Typy zgłoszeń',
'categories'	=>	'Kategorie',
'operatingsystems'	=>	'Systemy operacyjne',
'resolutions'	=>	'Decyzje',
'versions'	=>	'Wersje',
'severities'	=>	'Ważność',
'disabledaccount'	=>	'Twoje konto jest nieaktywne!<br/>Wylogowuję...',
'poweredby'	=>	'Napędzane przez Flyspray',

// Added in version 0.9.5

//'selectproject'	=>	'Lista zgłoszeń projektu:',
'show'		=>	'Pokaż',
'projects'	=>	'Projekty',
'adminmenu'	=>	'Menu Administratora',

// Added in version 0.9.6
'duplicated'	    =>	'Akcja powtórzona. Nastąpi przekierowanie na stronę główną.',
'allprojects'       =>	'dowolnego',
'selectproject'	      =>	'dla projektu:',
'tasksall'          =>  'Wszystkie zgłoszenia',
'tasksassigned'     =>  'Przydzielone mi',
'tasksreported'     =>  'Zgłoszone przeze mnie',
'taskswatched'      =>  'Obserwowane przeze mnie',
'lastsearch'	    =>  'Ostatnio wyszukiwane',

// Added in version 0.9.7
'adminreqwaiting'   =>   'Oczekujące prośby o administrację',



);
// vim:fenc=utf-8:enc=utf-8
?>
